# Major changes in version 0.7
- Replaced Mako with Jinja2 templates
- Add proper application structure description(QuickWeb_Application.md)
- 100% success with functional testing on Python2.7 / Python3.4
- 100% success with functional testing on Windows
